import { Platform } from "ionic-angular";
export declare class HockeyApp {
    private platform;
    private androidAppId;
    private iosAppId;
    private sendAutoUpdates;
    private ignoreErrorHeader;
    private checkForUpdatesMode;
    private window;
    constructor(platform: Platform);
    /**
     * Performs a request with `get` http method.
     * @param androidAppId          The Android ID of the app as provided by the HockeyApp portal.
     * @param iosAppId              The iOS ID of the app as provided by the HockeyApp portal.
     * @param autoSendCrashReports  Specifies whether you would like crash reports to be automatically sent to the HockeyApp server when the end user restarts the app. Default - false
     * @param ignoreDefaultHandler  Specifies whether you would like to display the standard dialog when the app is about to crash. This parameter is only relevant on Android. Default - false
     * @param checkForUpdatesMode   The option of whether to check for updates when the app starts (CHECK_ON_STARTUP) or manually (CHECK_MANUALLY) via checkHockeyAppUpdates() method. Default - CHECK_MANUALLY
     */
    start(androidAppId: string, iosAppId: string, sendAutoUpdates: boolean, ignoreErrorHeader: boolean, checkForUpdatesMode?: string): Promise<any>;
    /**
     * Logs an app-specific event for analytic purposes.
     * @param name      The name (e.g. "ITEM_ADDED") of the custom event that should be logged.
     */
    trackEvent(name: string): Promise<any>;
    /**
     * Check if there is a new version available to download. NOTE: This should not be called in production/release builds intended for the Google Play Store.
     */
    checkHockeyAppUpdates(): Promise<any>;
    /**
     * Immediately crashes the app. This is used strictly for testing the HockeyApp crash reporting capabilities.
     */
    forceCrash(): Promise<any>;
    /**
     * If you would like to include additional data to include with user feedback, you can call the following API and indicate whether to include a screen shot of the device and/or arbitrary data from your application at the time that the API is called.
     */
    composeFeedback(attachScreenshot: boolean, data: any): Promise<any>;
    /**
     * If you're using HockeyApp to distribute beta builds to your testers, then you'll likely also want to collect feedback from them in addition to viewing crash reports and usage metrics. To do this, simply call the following method in order to display a UI that allows your users to send app feedback directly to you:
     */
    feedback(): Promise<any>;
    /**
     * Attaches arbitrary metadata to the next crash report in order to provide more context about the user's state.
     * @param data A JavaScript object that describes the metadata (i.e. properties and values) that you would like to attach to the next crash report.
     */
    addMetaData(data: any): Promise<any>;
    /**
     * Set the user's e-mail address.
     * @param userEmail      The user's e-mail address.
     */
    setUserEmail(userEmail: string): Promise<any>;
    /**
     * Set the user's name.
     * @param userName      The user's name.
     */
    setUserName(userName: string): Promise<any>;
}
