var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Injectable } from '@angular/core';
import { Platform } from "ionic-angular";
var HockeyApp = (function () {
    //private loginMode = this.window[<any>'hockeyapp'].ANONYMOUS;
    //private androidAppSecret = ''; //if  loginMode is email only. iOS only works with anonymous
    function HockeyApp(platform) {
        this.platform = platform;
        this.sendAutoUpdates = false;
        this.ignoreErrorHeader = false;
        this.window = window;
    }
    /**
     * Performs a request with `get` http method.
     * @param androidAppId          The Android ID of the app as provided by the HockeyApp portal.
     * @param iosAppId              The iOS ID of the app as provided by the HockeyApp portal.
     * @param autoSendCrashReports  Specifies whether you would like crash reports to be automatically sent to the HockeyApp server when the end user restarts the app. Default - false
     * @param ignoreDefaultHandler  Specifies whether you would like to display the standard dialog when the app is about to crash. This parameter is only relevant on Android. Default - false
     */
    HockeyApp.prototype.start = function (androidAppId, iosAppId, sendAutoUpdates, ignoreErrorHeader) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            _this.androidAppId = androidAppId;
            _this.iosAppId = iosAppId;
            _this.sendAutoUpdates = sendAutoUpdates;
            _this.ignoreErrorHeader = ignoreErrorHeader;
            if (_this.window['hockeyapp']) {
                var appId = void 0;
                if (_this.platform.is('ios')) {
                    appId = _this.iosAppId;
                }
                else if (_this.platform.is('android')) {
                    appId = _this.androidAppId;
                }
                if (appId) {
                    _this.window['hockeyapp'].start(function (success) {
                        resolve(success);
                    }, function (err) {
                        reject(err);
                    }, appId, _this.sendAutoUpdates, _this.ignoreErrorHeader);
                }
                else {
                    reject('HockeyApp unable to start, no app id or unsupported platform');
                }
            }
            else {
                if (_this.platform.is('core') || _this.platform.is('mobileweb')) {
                    console.warn('HockeyApp unable to start on this platform');
                    resolve();
                }
                else {
                    reject('HockeyApp is not found, please make sure the cordova-hockeyapp-plugin is installed and on a supported platform');
                }
            }
        });
    };
    /**
     * Logs an app-specific event for analytic purposes.
     * @param name      The name (e.g. "ITEM_ADDED") of the custom event that should be logged.
     */
    HockeyApp.prototype.trackEvent = function (name) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (_this.window['hockeyapp']) {
                _this.window['hockeyapp'].trackEvent(function (success) {
                    resolve(success);
                }, function (err) {
                    reject(err);
                }, name);
            }
            else {
                if (_this.platform.is('core') || _this.platform.is('mobileweb')) {
                    console.warn('HockeyApp unable to trackEvent ' + name + ' on this platform');
                    resolve();
                }
                else {
                    reject('HockeyApp is not found, please make sure the cordova-hockeyapp-plugin is installed and on a supported platform');
                }
            }
        });
    };
    /**
     * Check if there is a new version available to download. NOTE: This should not be called in production/release builds intended for the Google Play Store.
     */
    HockeyApp.prototype.checkHockeyAppUpdates = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (_this.window['hockeyapp']) {
                _this.window['hockeyapp'].checkForUpdate(function (success) {
                    resolve(success);
                }, function (err) {
                    reject(err);
                });
            }
            else {
                if (_this.platform.is('core') || _this.platform.is('mobileweb')) {
                    console.warn('HockeyApp unable to check HockeyApp updates on this platform');
                    resolve();
                }
                else {
                    reject('HockeyApp is not found, please make sure the cordova-hockeyapp-plugin is installed and on a supported platform');
                }
            }
        });
    };
    /**
     * Immediately crashes the app. This is used strictly for testing the HockeyApp crash reporting capabilities.
     */
    HockeyApp.prototype.forceCrash = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (_this.window['hockeyapp']) {
                _this.window['hockeyapp'].forceCrash(function (success) {
                    resolve(success);
                }, function (err) {
                    reject(err);
                });
            }
            else {
                if (_this.platform.is('core') || _this.platform.is('mobileweb')) {
                    console.warn('HockeyApp unable to force crash on this platform');
                    resolve();
                }
                else {
                    reject('HockeyApp is not found, please make sure the cordova-hockeyapp-plugin is installed and on a supported platform');
                }
            }
        });
    };
    /**
     * If you would like to include additional data to include with user feedback, you can call the following API and indicate whether to include a screen shot of the device and/or arbitrary data from your application at the time that the API is called.
     */
    HockeyApp.prototype.composeFeedback = function (attachScreenshot, data) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (_this.window['hockeyapp']) {
                _this.window['hockeyapp'].composeFeedback(function (success) {
                    resolve(success);
                }, function (err) {
                    reject(err);
                }, attachScreenshot, data);
            }
            else {
                if (_this.platform.is('core') || _this.platform.is('mobileweb')) {
                    console.warn('HockeyApp unable to compose feedback on this platform');
                    resolve();
                }
                else {
                    reject('HockeyApp is not found, please make sure the cordova-hockeyapp-plugin is installed and on a supported platform');
                }
            }
        });
    };
    /**
     * If you're using HockeyApp to distribute beta builds to your testers, then you'll likely also want to collect feedback from them in addition to viewing crash reports and usage metrics. To do this, simply call the following method in order to display a UI that allows your users to send app feedback directly to you:
     */
    HockeyApp.prototype.feedback = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (_this.window['hockeyapp']) {
                _this.window['hockeyapp'].feedback(function (success) {
                    resolve(success);
                }, function (err) {
                    reject(err);
                });
            }
            else {
                if (_this.platform.is('core') || _this.platform.is('mobileweb')) {
                    console.warn('HockeyApp unable to feedback on this platform');
                    resolve();
                }
                else {
                    reject('HockeyApp is not found, please make sure the cordova-hockeyapp-plugin is installed and on a supported platform');
                }
            }
        });
    };
    /**
     * Attaches arbitrary metadata to the next crash report in order to provide more context about the user's state.
     * @param data A JavaScript object that describes the metadata (i.e. properties and values) that you would like to attach to the next crash report.
     */
    HockeyApp.prototype.addMetaData = function (data) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (_this.window['hockeyapp']) {
                _this.window['hockeyapp'].addMetaData(function (success) {
                    resolve(success);
                }, function (err) {
                    reject(err);
                }, data);
            }
            else {
                if (_this.platform.is('core') || _this.platform.is('mobileweb')) {
                    console.warn('HockeyApp unable to add meta data on this platform');
                    resolve();
                }
                else {
                    reject('HockeyApp is not found, please make sure the cordova-hockeyapp-plugin is installed and on a supported platform');
                }
            }
        });
    };
    return HockeyApp;
}());
HockeyApp = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [Platform])
], HockeyApp);
export { HockeyApp };
